California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 026 - INCREASES LEGISLATIVE VOTE REQUIREMENT TO TWO-THIRDS FOR STATE LEVIES & CHARGES. IMPOSES ADDITIONAL REQUIREMENT FOR VOTERS TO APPROVE LOCAL LEVIES & CHARGES WITH LIMITED EXCEPTIONS. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333283 | BALLOT INITIATIVE STRATEGY CENTER-CA OPPOSED TO PROP 23 AND PROP 26 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1331916 | NO ON 26, TEACHERS, POLICE OFFICERS AND OTHER PUBLIC AND PRIVATE EMPLOYEE GROUPS PROTECTING TAXPAYERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1323934 | STOP HIDDEN TAXES - NO ON 25 / YES ON 26, A COALITION OF TAXPAYERS AND EMPLOYERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1327926 | COMMUNITIES UNITED AGAINST PROPOSITION 23 AND 26, SPONOSRED BY ELLA BAKER CENTER FOR HUMAN RIGHTS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1318621 | CALIFORNIANS AGAINST HIGHER TAXES, A COALITION OF TAXPAYERS AND EMPLOYERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1327516 | TAXPAYERS AGAINST PROTECTING POLLUTERS NO ON PROPOSITION 26 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1331815 | CALIFORNIA ALLIANCE ACTION FUND: A COMMITTEE SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS FOR PROPOSITIONS 24, 25 AND AGAINST PROPOSITIONS 23, 26 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333478 | MARIN INSTITUTE CHARGE FOR HARM NO ON PROP 26 COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1332177 | ENVIRONMENTAL DEFENSE ACTION FUND SAY NO TO PROP 23 AND 26 COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288513 | CALIFORNIANS FOR CLEAN AIR AND CLEAN ENERGY JOBS, NO ON 23, NO ON 26, A PROJECT OF CALIFORNIA LEAGUE OF CONSERVATION VOTERS. | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1330171 | CLEAN ENERGY AND GOOD JOBS MOBILIZATION COMMITTEE - NO ON 23 AND 26 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1270683 | SMALL BUSINESS ACTION COMMITTEE PAC, YES ON 20 & 26, NO ON 25 & 27 | SUPPORT